@@ -10,24 +10,19 @@ g.analyse.perday = function(ndays, firstmidnighti, time, nfeatures,
   #get input variables
   input = list(...)
   
-  expectedArgs = c("params_247", "params_phyact", 
-                   "ndays", "firstmidnighti", "time", "nfeatures", 
-                   "midnightsi", "metashort", "averageday",
-                   "doiglevels", "nfulldays","lastmidnight", "ws3", "ws2", "qcheck",
-                   "fname", "idloc", "sensor.location", "wdayname", "tooshort", "includedaycrit",
-                   "doquan", "quantiletype", "doilevels", "domvpa",
-                   "mvpanames", "wdaycode", "ID",
-                   "deviceSerialNumber", "ExtFunColsi", "myfun", "desiredtz") 
-  if (any(names(input) %in% expectedArgs == FALSE) |
-      any(!unlist(lapply(expectedArgs, FUN = exists)))) {
-    # Extract and check parameters if user provides more arguments than just the parameter arguments
+  if (length(input) > 0 ||
+      length(params_247) == 0 || length(params_phyact) == 0) {
+    # Extract and check parameters if user provides more arguments than just the parameter arguments,
+    # or if params_[...] aren't specified (so need to be filled with defaults).
     # So, inside GGIR this will not be used, but it is used when g.analyse is used on its own
     # as if it was still the old g.analyse function
     params = extract_params(params_247 = params_247,
                             params_phyact = params_phyact,
-                            input = input) # load default parameters
+                            input = input,
+                            params2check = c("247", "phyact")) # load default parameters
     params_247 = params$params_247
     params_phyact = params$params_phyact
+    rm(params)
   }
   
   startatmidnight = endatmidnight = 0
