@@ -1,5 +1,6 @@
 g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
-                    dayborder = 0, TimeSegments2Zero = c(), acc.metric = "ENMO", ...) {
+                    dayborder = 0, TimeSegments2Zero = c(), acc.metric = "ENMO", 
+                    ID, ...) {
   
   #get input variables
   input = list(...)
@@ -14,7 +15,7 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
     params_cleaning = params$params_cleaning
     rm(params)
   }
-
+  
   windowsizes = M$windowsizes #default: c(5,900,3600)
   metashort = M$metashort
   metalong = M$metalong
@@ -95,8 +96,72 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
   lastmidnight = dmidn$lastmidnight;    lastmidnighti = dmidn$lastmidnighti
   midnights = dmidn$midnights;          midnightsi = dmidn$midnightsi
   #===================================================================
-  # Select data based on strategy
-  if (params_cleaning[["strategy"]] == 1) { 	#protocol based data selection
+  # Trim data based on study_dates_file
+  study_dates_log_used = FALSE
+  if (!is.null(params_cleaning[["study_dates_file"]])) {
+    # Read content of study dates file 
+    studyDates = data.table::fread(file = params_cleaning[["study_dates_file"]], data.table = FALSE)
+    # Check ID and date formats
+    studyDates = check_log(log = studyDates, 
+                           dateformat = params_cleaning[["study_dates_dateformat"]], 
+                           colid = 1, datecols = 2:3, 
+                           logPath = params_cleaning[["study_dates_file"]],
+                           logtype = "study dates log")
+    # identify first and last study dates
+    rowID = which(studyDates[, 1] == ID)
+    if (length(rowID) > 0) {
+      if (length(rowID) > 1) {
+        # this is in the unlikely event that an ID appears twice in the log
+        rowID = rowID[1]
+        warning(paste0("The ID ", ID, " appears twice in the study dates log"), call. = FALSE)
+      }
+      # expected first and last midnight
+      firstmidnight = as.Date(studyDates[rowID, 2], format = params_cleaning[["study_dates_dateformat"]])
+      lastmidnight = as.Date(studyDates[rowID, 3], format = params_cleaning[["study_dates_dateformat"]])
+      # find the dates in metalong
+      firstmidnighti = midnightsi[grep(firstmidnight, midnights)]
+      lastmidnighti = midnightsi[grep(lastmidnight, midnights) + 1] # plus 1 to include the reported date in log
+      # trim data at the beginning
+      if (length(firstmidnighti) > 0) {
+        r4[1:(firstmidnighti - 1)] = 1
+        study_dates_log_used = TRUE
+      } else {
+        # if midnight timestamp for the date is not available, 
+        # do not trim the data and recover the firstmidnight value
+        firstmidnighti = dmidn$firstmidnighti
+        firstmidnight = dmidn$firstmidnight
+        # warning(paste0("The start date provided in the study dates file for ID = ", 
+        #                ID, "is not within the dates available in the recording. ",
+        #                "The data was not trimmed at the beginning of the recording."), call. = FALSE)
+      }
+      # trim data at the end
+      if (length(lastmidnighti) > 0 & !is.na(lastmidnighti)) {
+        r4[lastmidnighti:nrow(r4)] = 1
+        study_dates_log_used = TRUE
+      } else {
+        # if midnight timestamp for the date is not available, 
+        # do not trim the data and recover the lastmidnight value
+        lastmidnighti = dmidn$lastmidnighti
+        lastmidnight = dmidn$lastmidnight
+        # warning(paste0("The end date provided in the study dates file for ID = ", 
+        #                ID, "is not within the dates available in the recording. ",
+        #                "The data was not trimmed at the end of the recording."), call. = FALSE)
+      }
+      # cut out r4 to apply strategies only on the trimmed portion of data
+      # after application of strategies, r4 would reset to the original length
+      if (study_dates_log_used == TRUE) {
+        r4_bu = r4 # backup copy of r4 before cutting it to be imputed later on
+        r4 = as.matrix(r4[which(r4[,1] == 0),])
+      }
+    } else if (length(rowID) == 0) {
+      warning(paste0("The ID ", ID, " does not appear  in the study dates log ",
+                     "the full recording has been considered within the study ",
+                     "protocol selection"), call. = FALSE)
+    }
+  }
+  #===================================================================
+  # Select data based on data_masking_strategy
+  if (params_cleaning[["data_masking_strategy"]] == 1) { 	#protocol based data selection
     if (params_cleaning[["hrs.del.start"]] > 0) {
       r4[1:(params_cleaning[["hrs.del.start"]]*(3600/ws2))] = 1
     }
@@ -113,16 +178,23 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
     }
     starttimei = 1
     endtimei = length(r4)
-  } else if (params_cleaning[["strategy"]] == 2) { #midnight to midnight strategy
+  } else if (params_cleaning[["data_masking_strategy"]] == 2) { #midnight to midnight data_masking_strategy
     starttime = firstmidnight
-    endtime = lastmidnight
-    starttimei = firstmidnighti
-    endtimei = lastmidnighti
-    if (firstmidnighti != 1) { #ignore everything before the first midnight
-      r4[1:(firstmidnighti - 1)] = 1 #-1 because first midnight 00:00 itself contributes to the first full day
+    endtime = lastmidnight  
+    # only apply data_masking_strategy 2 if study dates log is not used for trimming the data,
+    # otherwise the data already start and finishes at midnight
+    if (study_dates_log_used == FALSE) {
+      starttimei = firstmidnighti
+      endtimei = lastmidnighti
+      if (firstmidnighti != 1) { #ignore everything before the first midnight
+        r4[1:(firstmidnighti - 1)] = 1 #-1 because first midnight 00:00 itself contributes to the first full day
+      }
+      r4[(lastmidnighti):length(r4)] = 1  #ignore everything after the last midnight
+    } else {
+      starttimei = 1
+      endtimei = length(r4)
     }
-    r4[(lastmidnighti):length(r4)] = 1  #ignore everything after the last midnight
-  } else if (params_cleaning[["strategy"]] %in% c(3, 5)) { #select X most active days
+  } else if (params_cleaning[["data_masking_strategy"]] %in% c(3, 5)) { #select X most active days
     #==========================================
     # Look out for X most active days and use this to define window of interest
     if (acc.metric %in% colnames(M$metashort)) {
@@ -135,7 +207,7 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
     r2tempe = rep(r2, each = (ws2/ws3))
     r1tempe = rep(r1, each = (ws2/ws3))
     atest[which(r2tempe == 1 | r1tempe == 1)] = 0
-    if (params_cleaning[["strategy"]] == 3) {
+    if (params_cleaning[["data_masking_strategy"]] == 3) {
       # Select the most active 24-h blocks by a rolling window of windowsizes[3]
       NDAYS = length(atest) / n_ws3_perday
       # rolling window in ws3
@@ -179,9 +251,14 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
       if (LD < 1440) {
         r4 = r4[1:floor(LD/(ws2/60))]
       }
-    } else if (params_cleaning[["strategy"]] == 5) {
+    } else if (params_cleaning[["data_masking_strategy"]] == 5) {
       # Select the most active calendar days
       atestlist = c()
+      # readjust midnightsi if study dates log used for trimming the data
+      if (study_dates_log_used == TRUE) {
+        midnights2keep = which(midnightsi >= firstmidnighti & midnightsi <= lastmidnighti)
+        midnightsi = midnightsi[midnights2keep]
+      }
       for (ati in 1:length(midnightsi)) {
         p0 = ((midnightsi[ati] * ws2/ws3) - ws2/ws3) + 1
         p1 = ((midnightsi[ati + params_cleaning[["ndayswindow"]]] * ws2/ws3) - ws2/ws3)
@@ -194,21 +271,40 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
       if (!is.null(atestlist)) atik = which(atestlist == max(atestlist))[1]
       #ignore everything before the first ndayswindow midnight plus hrs.del.start
       ignore_until = (midnightsi[atik]) + (params_cleaning[["hrs.del.start"]]*(3600/ws2)) - 1 # minus 1 for not ignoring the first epoch in ndayswindow
-      if (ignore_until > 0) r4[1:ignore_until] = 1 #-1 because first midnight 00:00 itself contributes to the first full day
+      if (ignore_until > 0) {
+        if (study_dates_log_used == TRUE) {
+          ignore_until = ignore_until - firstmidnighti + 1
+        }
+        r4[1:ignore_until] = 1 
+      }
       #ignore everything after the last midnight plus hrs.del.end
       ignore_from = midnightsi[atik + params_cleaning[["ndayswindow"]]] - (params_cleaning[["hrs.del.end"]]*(3600/ws2))
+      if (study_dates_log_used == TRUE) {
+        ignore_from = ignore_from - firstmidnighti + 1
+        if (ignore_from >= length(r4)) ignore_from = length(r4)
+      }
       # if ndayswindow is higher than number of midnights, use last midnight
       if (is.na(ignore_from)) ignore_from = midnightsi[length(midnightsi)] - (params_cleaning[["hrs.del.end"]]*(3600/ws2))
-      r4[ignore_from:length(r4)] = 1
+      # if ignore_from == length(r4) it means that recording ends at midnight 
+      # and the code should not ignore anything at the end of the recording
+      if (ignore_from < length(r4)) r4[ignore_from:length(r4)] = 1
     }
     starttimei = 1
     endtimei = length(r4)
-    
-  } else if (params_cleaning[["strategy"]] == 4) { #from first midnight to end of recording
+  } else if (params_cleaning[["data_masking_strategy"]] == 4) { #from first midnight to end of recording
     starttime = firstmidnight
-    starttimei = firstmidnighti
-    if (firstmidnighti != 1) { #ignore everything before the first midnight
-      r4[1:(firstmidnighti - 1)] = 1 #-1 because first midnight 00:00 itself contributes to the first full day
+    endtime = lastmidnight  
+    # only apply data_masking_strategy 4 if study dates log is not used for trimming the data,
+    # otherwise the data already start and finishes at midnight
+    if (study_dates_log_used == FALSE) {
+      starttimei = firstmidnighti
+      endtimei = lastmidnighti
+      if (firstmidnighti != 1) { #ignore everything before the first midnight
+        r4[1:(firstmidnighti - 1)] = 1 # -1 because first midnight 00:00 itself contributes to the first full day
+      }
+    } else {
+      starttimei = 1
+      endtimei = length(r4)
     }
   }
   # Mask data based on maxdur
@@ -217,12 +313,23 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
   }
   # Mask data based on max_calendar_days
   if (params_cleaning[["max_calendar_days"]] > 0) {
-    dates = as.Date(iso8601chartime2POSIX(M$metalong$timestamp,tz = desiredtz))
+    # get dates that are part of the study protocol
+    if (study_dates_log_used == TRUE) {
+      dates = as.Date(iso8601chartime2POSIX(M$metalong$timestamp[firstmidnighti:(lastmidnighti - 1)], tz = desiredtz))
+    } else {
+      dates = as.Date(iso8601chartime2POSIX(M$metalong$timestamp, tz = desiredtz))
+    }
     if (params_cleaning[["max_calendar_days"]] < length(unique(dates))) {
       lastDateToInclude = sort(unique(dates))[params_cleaning[["max_calendar_days"]]]
       r4[which(dates > lastDateToInclude)] = 1
     }
   }
+  #===================================================================
+  # if data selected based on study dates log, recover the original length of r4
+  if (study_dates_log_used == TRUE) {
+    r4_bu[which(r4_bu == 0),] = r4
+    r4 = r4_bu
+  }
   #========================================================================================
   # Impute ws3 second data based on ws2 minute estimates of non-wear time
   r5 = r1 + r2 + r3 + r4
@@ -290,7 +397,7 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
   metashort[,2:ncol(metashort)] = round(metashort[,2:ncol(metashort)], digits = n_decimal_places)
   rout = data.frame(r1 = r1, r2 = r2, r3 = r3, r4 = r4, r5 = r5, stringsAsFactors = TRUE)
   invisible(list(metashort = metashort, rout = rout, r5long = r5long, dcomplscore = dcomplscore,
-                 averageday = averageday, windowsizes = windowsizes, strategy = params_cleaning[["strategy"]],
+                 averageday = averageday, windowsizes = windowsizes, data_masking_strategy = params_cleaning[["data_masking_strategy"]],
                  LC = LC, LC2 = LC2, hrs.del.start = params_cleaning[["hrs.del.start"]], hrs.del.end = params_cleaning[["hrs.del.end"]],
                  maxdur = params_cleaning[["maxdur"]]))
 }
