@@ -4,7 +4,7 @@ updateBlocksize = function(blocksize=c(), bsc_qc=data.frame(time=c(),size=c()))
   }
   gco = gc()
   memuse = gco[2,2] #memuse in mb
-  bsc_qc_new_row = data.frame(time=as.character(Sys.time()),size=memuse,stringsAsFactors = FALSE)
+  bsc_qc_new_row = data.frame(time=format(Sys.time()),size=memuse,stringsAsFactors = FALSE)
   if (nrow(bsc_qc) == 0) {
     bsc_qc = bsc_qc_new_row
   } else {
